- All Implemented Interfaces:
Serializable,Comparable<BitsPerSample>,Constable
The
BitsPerSample enumeration defines some common bits/sample per
channel constants.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionintReturns the bits/sample per channel.intReturns the bytes/sample per channel.static BitsPerSampleRetrieves the lowest bits/sample resolution.static BitsPerSampleRetrieves the lowest bits/sample resolution.Retrieves the next higher bits/sample or null if it is already the highest bits/sample.Retrieves the previous lower bits/sample or null if it is already the lowest bits/sample.static BitsPerSampleReturns the enum constant of this class with the specified name.static BitsPerSample[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
LOW_RES
Low resolution of 8 bits/sample and channel. -
HIGH_RES
High resolution of 16 bits/sample and channel.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getBitCount
public int getBitCount()Returns the bits/sample per channel.- Returns:
- The bits/sample for this
BitsPerSample.
-
getByteCount
public int getByteCount()Returns the bytes/sample per channel.- Returns:
- The bytes/sample for this
BitsPerSample.
-
getLowestResolution
Retrieves the lowest bits/sample resolution.- Returns:
- The lowest resolution.
-
getHigestResolution
Retrieves the lowest bits/sample resolution.- Returns:
- The highest resolution.
-
getNextHigherResolution
Retrieves the next higher bits/sample or null if it is already the highest bits/sample.- Returns:
- The next higher bits/sample or null if already the highest bits / sample.
-
getPreviousLowerResolution
Retrieves the previous lower bits/sample or null if it is already the lowest bits/sample.- Returns:
- The previous lower bits/sample or null if already the lowest bits/sample.
-