- All Superinterfaces:
org.refcodes.mixin.IndexAccessor,SamplingRateAccessor,SoundSample,org.refcodes.mixin.TimeStampAccessor
- All Known Subinterfaces:
MonoSampleBuilder
- All Known Implementing Classes:
MonoSampleBuilderImpl,MonoSampleImpl
A
MonoSample is a SoundSample supporting just one single
channel.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.IndexAccessor
org.refcodes.mixin.IndexAccessor.IndexBuilder<B extends org.refcodes.mixin.IndexAccessor.IndexBuilder<B>>, org.refcodes.mixin.IndexAccessor.IndexMutator, org.refcodes.mixin.IndexAccessor.IndexPropertyNested classes/interfaces inherited from interface org.refcodes.audio.SamplingRateAccessor
SamplingRateAccessor.SamplingRateBuilder<B extends SamplingRateAccessor.SamplingRateBuilder<B>>, SamplingRateAccessor.SamplingRateMutator, SamplingRateAccessor.SamplingRatePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TimeStampAccessor
org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B extends org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B>>, org.refcodes.mixin.TimeStampAccessor.TimeStampMutator, org.refcodes.mixin.TimeStampAccessor.TimeStampProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault doubleReturns the sample's data for the according time positioning.Methods inherited from interface org.refcodes.mixin.IndexAccessor
getIndexMethods inherited from interface org.refcodes.audio.SamplingRateAccessor
getSamplingRateMethods inherited from interface org.refcodes.audio.SoundSample
getChannelCount, getSampleData, getTimeStamp
-
Method Details
-
getMonoData
default double getMonoData()Returns the sample's data for the according time positioning. A sample is a value or set of values at a point in time. In case of mono audio, a sample represents a single value, in case of stereo audio, a sample represents a set of values, one value represents one channel (e.g. two channels when we have a left and a right speaker).- Returns:
- The sample's data for the according time positioning.
-