java.lang.Object
org.refcodes.audio.SoundSampleImpl
org.refcodes.audio.MonoSampleImpl
- All Implemented Interfaces:
MonoSample,SamplingRateAccessor,SoundSample,org.refcodes.mixin.IndexAccessor,org.refcodes.mixin.TimeStampAccessor
A
MonoSampleImpl represents a single amplitude (one for the mono
channel) assigned to an according time positioning.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.IndexAccessor
org.refcodes.mixin.IndexAccessor.IndexBuilder<B extends org.refcodes.mixin.IndexAccessor.IndexBuilder<B>>, org.refcodes.mixin.IndexAccessor.IndexMutator, org.refcodes.mixin.IndexAccessor.IndexPropertyNested classes/interfaces inherited from interface org.refcodes.audio.SamplingRateAccessor
SamplingRateAccessor.SamplingRateBuilder<B extends SamplingRateAccessor.SamplingRateBuilder<B>>, SamplingRateAccessor.SamplingRateMutator, SamplingRateAccessor.SamplingRatePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TimeStampAccessor
org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B extends org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B>>, org.refcodes.mixin.TimeStampAccessor.TimeStampMutator, org.refcodes.mixin.TimeStampAccessor.TimeStampProperty -
Constructor Summary
ConstructorsConstructorDescriptionMonoSampleImpl(double aSample) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(double aTimeMillis, double aSample) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(double aTimeMillis, double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(long aIndex, double aSample) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(long aIndex, double aTimeMillis, double aSample) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(long aIndex, double aTimeMillis, double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(long aIndex, double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.MonoSampleImpl(MonoSample aSample) Constructs aMonoSampleinstance with the according sound sample's settings -
Method Summary
Methods inherited from class org.refcodes.audio.SoundSampleImpl
getIndex, getSampleData, getSamplingRate, getTimeStampMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.IndexAccessor
getIndexMethods inherited from interface org.refcodes.audio.MonoSample
getMonoDataMethods inherited from interface org.refcodes.audio.SamplingRateAccessor
getSamplingRateMethods inherited from interface org.refcodes.audio.SoundSample
getChannelCount, getSampleData, getTimeStamp
-
Constructor Details
-
MonoSampleImpl
Constructs aMonoSampleinstance with the according sound sample's settings- Parameters:
aSample- The mono sample (a single value representing the mono channel) for the related time positioning.
-
MonoSampleImpl
public MonoSampleImpl(double aSample) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aSample- The mono sample (a single value representing the mono channel) for the related time positioning.
-
MonoSampleImpl
public MonoSampleImpl(double aTimeMillis, double aSample) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aTimeMillis- The time positioning of this sound sample.aSample- The mono sample (a single value representing the mono channel) for the related time positioning.
-
MonoSampleImpl
public MonoSampleImpl(double aTimeMillis, double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aTimeMillis- The time positioning of this sound sample.aSample- The mono sample (a single value representing the mono channel) for the related time positioning.aSamplingRate- The sampling rate for the given sample.
-
MonoSampleImpl
public MonoSampleImpl(double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aSample- The mono sample (a single value representing the mono channel) for the related time positioning.aSamplingRate- The sampling rate for the given sample.
-
MonoSampleImpl
public MonoSampleImpl(long aIndex, double aSample) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aIndex- The index of the sample according to its position in the sample sequence (e.g. sound file).aSample- The mono sample (a single value representing the mono channel) for the related time positioning.
-
MonoSampleImpl
public MonoSampleImpl(long aIndex, double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aIndex- The index of the sample according to its position in the sample sequence (e.g. sound file).aSample- The mono sample (a single value representing the mono channel) for the related time positioning.aSamplingRate- The sampling rate for the given sample.
-
MonoSampleImpl
public MonoSampleImpl(long aIndex, double aTimeMillis, double aSample) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aIndex- The index of the sample according to its position in the sample sequence (e.g. sound file).aTimeMillis- The time positioning of this sound sample.aSample- The mono sample (a single value representing the mono channel) for the related time positioning.
-
MonoSampleImpl
public MonoSampleImpl(long aIndex, double aTimeMillis, double aSample, int aSamplingRate) Constructs aMonoSampleinstance with the according time and sample settings.- Parameters:
aIndex- The index of the sample according to its position in the sample sequence (e.g. sound file).aTimeMillis- The time positioning of this sound sample.aSample- The mono sample (a single value representing the mono channel) for the related time positioning.aSamplingRate- The sampling rate for the given sample.
-
-
Method Details
-
toString
- Overrides:
toStringin classSoundSampleImpl
-