Module org.refcodes.audio
Package org.refcodes.audio
Interface SampleBuilder<S extends SoundSample,B extends SampleBuilder<S,B>>
-
- Type Parameters:
S- TheSoundSample(sub-)type on which theSampleBuilderimplementation is to operate on.B- TheSampleBuilderimplementing thisSampleBuilder.
- All Superinterfaces:
org.refcodes.mixin.IndexAccessor,org.refcodes.mixin.IndexAccessor.IndexBuilder<B>,org.refcodes.mixin.IndexAccessor.IndexMutator,org.refcodes.mixin.IndexAccessor.IndexProperty,SamplingRateAccessor,SamplingRateAccessor.SamplingRateBuilder<B>,SamplingRateAccessor.SamplingRateMutator,SamplingRateAccessor.SamplingRateProperty,SoundSample,org.refcodes.mixin.TimeStampAccessor,org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B>,org.refcodes.mixin.TimeStampAccessor.TimeStampMutator,org.refcodes.mixin.TimeStampAccessor.TimeStampProperty
- All Known Subinterfaces:
MonoSampleBuilder,SoundSampleBuilder
- All Known Implementing Classes:
MonoSampleBuilderImpl,SoundSampleBuilderImpl
public interface SampleBuilder<S extends SoundSample,B extends SampleBuilder<S,B>> extends SoundSample, org.refcodes.mixin.IndexAccessor.IndexProperty, org.refcodes.mixin.IndexAccessor.IndexBuilder<B>, SamplingRateAccessor.SamplingRateProperty, SamplingRateAccessor.SamplingRateBuilder<B>, org.refcodes.mixin.TimeStampAccessor.TimeStampProperty, org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B>
Base interface for sample builders such as theMonoSampleBuilderor theSoundSampleBuilder.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.IndexAccessor
org.refcodes.mixin.IndexAccessor.IndexBuilder<B extends org.refcodes.mixin.IndexAccessor.IndexBuilder<B>>, org.refcodes.mixin.IndexAccessor.IndexMutator, org.refcodes.mixin.IndexAccessor.IndexProperty
-
Nested classes/interfaces inherited from interface org.refcodes.audio.SamplingRateAccessor
SamplingRateAccessor.SamplingRateBuilder<B extends SamplingRateAccessor.SamplingRateBuilder<B>>, SamplingRateAccessor.SamplingRateMutator, SamplingRateAccessor.SamplingRateProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TimeStampAccessor
org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B extends org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B>>, org.refcodes.mixin.TimeStampAccessor.TimeStampMutator, org.refcodes.mixin.TimeStampAccessor.TimeStampProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default voidupdateTimeStamp()Calculates the time stamp from the sampling rate and the index and sets the time stamp property (as ofSoundSample.getTimeStamp()).-
Methods inherited from interface org.refcodes.mixin.IndexAccessor.IndexBuilder
withDecreaseIndex, withIncreaseIndex, withIndex
-
Methods inherited from interface org.refcodes.mixin.IndexAccessor.IndexMutator
decreaseIndex, increaseIndex, resetIndex, setIndex
-
Methods inherited from interface org.refcodes.audio.SamplingRateAccessor
getSamplingRate
-
Methods inherited from interface org.refcodes.audio.SamplingRateAccessor.SamplingRateBuilder
withSamplingRate
-
Methods inherited from interface org.refcodes.audio.SamplingRateAccessor.SamplingRateMutator
setSamplingRate
-
Methods inherited from interface org.refcodes.audio.SamplingRateAccessor.SamplingRateProperty
letSamplingRate
-
Methods inherited from interface org.refcodes.audio.SoundSample
getChannelCount, getSampleData, getTimeStamp
-
-
-
-
Method Detail
-
updateTimeStamp
default void updateTimeStamp()
Calculates the time stamp from the sampling rate and the index and sets the time stamp property (as ofSoundSample.getTimeStamp()).
-
-