-
- Type Parameters:
S- The type of the sample to be used.
- All Superinterfaces:
AutoCloseable,org.refcodes.mixin.IndexAccessor,org.refcodes.io.RowReader<S>,SamplingRateAccessor
- All Known Subinterfaces:
MonoSampleReader,SoundSampleReader
- All Known Implementing Classes:
AbstractCsvSampleReader,CsvMonoSampleReader,CsvSoundSampleReader
public interface SampleReader<S extends SoundSample> extends AutoCloseable, org.refcodes.io.RowReader<S>, SamplingRateAccessor, org.refcodes.mixin.IndexAccessor
TheSampleReaderreads sound samples from a stream or a file.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.IndexAccessor
org.refcodes.mixin.IndexAccessor.IndexBuilder<B extends org.refcodes.mixin.IndexAccessor.IndexBuilder<B>>, org.refcodes.mixin.IndexAccessor.IndexMutator, org.refcodes.mixin.IndexAccessor.IndexProperty
-
Nested classes/interfaces inherited from interface org.refcodes.audio.SamplingRateAccessor
SamplingRateAccessor.SamplingRateBuilder<B extends SamplingRateAccessor.SamplingRateBuilder<B>>, SamplingRateAccessor.SamplingRateMutator, SamplingRateAccessor.SamplingRateProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default SnextSample()Reads the nextSoundSample, equivalent toRowReader.nextRow()with a semantically stronger method name..-
Methods inherited from interface java.lang.AutoCloseable
close
-
Methods inherited from interface org.refcodes.audio.SamplingRateAccessor
getSamplingRate
-
-
-
-
Method Detail
-
nextSample
default S nextSample() throws IOException
Reads the nextSoundSample, equivalent toRowReader.nextRow()with a semantically stronger method name..- Returns:
- The accordingly read
SoundSample. - Throws:
IOException- thrown in case there was an I/O related problem.
-
-