Module org.refcodes.audio
Package org.refcodes.audio
Interface SamplingRateAccessor.SamplingRateProperty
- All Superinterfaces:
SamplingRateAccessor,SamplingRateAccessor.SamplingRateMutator
- All Known Subinterfaces:
CsvSampleWriter<S,,B> CurveFunctionSoundSampleBuilder,LineOutSampleWriter<S,,B> MonoSampleBuilder,MonoSampleWriter<B>,SampleBuilder<S,,B> SampleWriter<S,,B> SoundSampleBuilder,SoundSampleWriter<B>,WavSampleWriter<S,B>
- All Known Implementing Classes:
AbstractCsvSampleWriter,AbstractLineOutSampleWriter,AbstractSvgSampleWriter,AbstractWavSampleWriter,CsvMonoSampleWriter,CsvSoundSampleWriter,CurveFunctionSoundSampleBuilderImpl,LineOutMonoSampleWriter,LineOutSoundSampleWriter,MonoSampleBuilderImpl,SoundSampleBuilderImpl,SvgMonoSampleWriter,WavMonoSampleWriter,WavSoundSampleWriter
- Enclosing interface:
- SamplingRateAccessor
public static interface SamplingRateAccessor.SamplingRateProperty
extends SamplingRateAccessor, SamplingRateAccessor.SamplingRateMutator
Provides a sampling rate property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.audio.SamplingRateAccessor
SamplingRateAccessor.SamplingRateBuilder<B extends SamplingRateAccessor.SamplingRateBuilder<B>>, SamplingRateAccessor.SamplingRateMutator, SamplingRateAccessor.SamplingRateProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault intletSamplingRate(int aSamplingRate) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given integer (setter) as ofSamplingRateAccessor.SamplingRateMutator.setSamplingRate(int)and returns the very same value (getter).Methods inherited from interface org.refcodes.audio.SamplingRateAccessor
getSamplingRateMethods inherited from interface org.refcodes.audio.SamplingRateAccessor.SamplingRateMutator
setSamplingRate
-
Method Details
-
letSamplingRate
default int letSamplingRate(int aSamplingRate) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given integer (setter) as ofSamplingRateAccessor.SamplingRateMutator.setSamplingRate(int)and returns the very same value (getter).- Parameters:
aSamplingRate- The integer to set (viaSamplingRateAccessor.SamplingRateMutator.setSamplingRate(int)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-