Interface SoundSample

All Superinterfaces:
org.refcodes.mixin.IndexAccessor, SamplingRateAccessor, org.refcodes.mixin.TimeStampAccessor
All Known Subinterfaces:
MonoSample, MonoSampleBuilder, SampleBuilder<S,B>, SoundSampleBuilder
All Known Implementing Classes:
MonoSampleBuilderImpl, MonoSampleImpl, SoundSampleBuilderImpl, SoundSampleImpl

public interface SoundSample extends SamplingRateAccessor, org.refcodes.mixin.IndexAccessor, org.refcodes.mixin.TimeStampAccessor
A SoundSample represents a sample assigned to an according time positioning. A sample is a value or set of values at a point in time. In case of mono audio, a sample represents a single value, in case of stereo audio, a sample represents a set of values, one value represents one channel (e.g. two channels when we have a left and a right speaker).