Uses of Interface
org.refcodes.audio.MonoSample
-
Uses of MonoSample in org.refcodes.audio
Subinterfaces of MonoSample in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceTheMonoSampleBuilderextends theSoundSamplewith builder functionality.Classes in org.refcodes.audio that implement MonoSampleModifier and TypeClassDescriptionclassAMonoSampleBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classAMonoSampleImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.Methods in org.refcodes.audio that return MonoSampleModifier and TypeMethodDescriptionCurveFunctionSoundSampleBuilder.next()Returns the nextMonoSamplefor the current index (as ofCurveFunctionSoundSampleBuilder.getIndex()) as well as for the other builder's settings and increases the index by one.CurveFunctionSoundSampleBuilderImpl.next()Returns the nextMonoSamplefor the current index (as ofCurveFunctionSoundSampleBuilder.getIndex()) as well as for the other builder's settings and increases the index by one.CsvMonoSampleReader.nextRow()CurveFunctionSoundSampleBuilder.toMonoSample()Creates aMonoSampleas of the builder's settings.CurveFunctionSoundSampleBuilder.toMonoSample(int aIndex) Creates aMonoSamplefor the given index and the the builder's settings.CurveFunctionSoundSampleBuilderImpl.toMonoSample()Creates aMonoSampleas of the builder's settings.CurveFunctionSoundSampleBuilderImpl.toMonoSample(int index) Creates aMonoSamplefor the given index and the the builder's settings.Methods in org.refcodes.audio with parameters of type MonoSampleModifier and TypeMethodDescriptionvoidCsvMonoSampleWriter.writeNext(MonoSample aSample) Writes the next samples, one sample for each channel.voidLineOutMonoSampleWriter.writeNext(MonoSample aSample) Writes the next samples, one sample for each channel.voidSvgMonoSampleWriter.writeNext(MonoSample aSample) Writes the next samples, one sample for each channel.voidWavMonoSampleWriter.writeNext(MonoSample aSample) Writes the next samples, one sample for each channel.Constructors in org.refcodes.audio with parameters of type MonoSampleModifierConstructorDescriptionMonoSampleBuilderImpl(MonoSample aSample) Constructs aMonoSampleinstance with the according sound sample's settingsMonoSampleImpl(MonoSample aSample) Constructs aMonoSampleinstance with the according sound sample's settings