Uses of Interface
org.refcodes.audio.SampleReader
-
Uses of SampleReader in org.refcodes.audio
Subinterfaces of SampleReader in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceTheMonoSampleReaderreads sound samples from a stream or a file.interfaceTheSoundSampleReaderreads sound samples from a stream or a file.Classes in org.refcodes.audio that implement SampleReaderModifier and TypeClassDescriptionclassAbstractCsvSampleReader<S extends SoundSample>TheAbstractCsvSampleReaderprovides a foundation to read sound samples from a CSV file.classTheCsvMonoSampleReaderprovides means to read sound samples from a CSV file.classTheCsvSoundSampleReaderprovides means to read sound samples from a CSV file.