Uses of Interface
org.refcodes.audio.SampleWriter
-
Uses of SampleWriter in org.refcodes.audio
Classes in org.refcodes.audio with type parameters of type SampleWriterModifier and TypeClassDescriptionclassAbstractSvgSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheAbstractSvgSampleWriterprovides a foundation to write sound samples to a SVG file.interfaceSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheSampleWriterwrites sound samples to a stream or a file.Subinterfaces of SampleWriter in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> Base definition of a WAV sample writer.interfaceLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> Base definition of a line-out sample writer.interfaceMonoSampleWriter<B extends MonoSampleWriter<B>>TheMonoSampleWriterwrites sound samples to a stream or a file.interfaceSoundSampleWriter<B extends SoundSampleWriter<B>>TheSoundSampleWriterwrites sound samples to a stream or a file.interfaceWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> Base definition of a WAV sample writer.Classes in org.refcodes.audio that implement SampleWriterModifier and TypeClassDescriptionclassAbstractCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> TheAbstractCsvSampleWriterprovides a foundation to write sound samples to a CSV file.classAbstractLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> TheAbstractLineOutSampleWriterprovides a foundation means to write sound samples to a line-out device.classAbstractSvgSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheAbstractSvgSampleWriterprovides a foundation to write sound samples to a SVG file.classAbstractWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> TheAbstractWavSampleWriterprovides a foundation means to write sound samples to a WAV file.classTheCsvMonoSampleWriterprovides means to write sound samples to a CSV file.classTheCsvSoundSampleWriterprovides means to write sound samples to a CSV file.classTheLineOutMonoSampleWriterprovides means to write sound samples to a line-out device.classTheLineOutSoundSampleWriterprovides means to write sound samples to a line-out device.classTheSvgMonoSampleWriterprovides means to write sound samples to a SVG file.classTheWavMonoSampleWriterprovides means to write sound samples to a WAV file.classTheWavSoundSampleWriterprovides means to write sound samples to a WAV file.