Uses of Enum Class
org.refcodes.audio.SamplingRate
-
Uses of SamplingRate in org.refcodes.audio
Subclasses with type arguments of type SamplingRate in org.refcodes.audioModifier and TypeClassDescriptionenumTheSamplingRateenumeration defines some common sampling rates.Methods in org.refcodes.audio that return SamplingRateModifier and TypeMethodDescriptionstatic SamplingRateSamplingRate.getHigestSamplingRate()Retrieves the highest sampling rate.static SamplingRateSamplingRate.getLowestSamplingRate()Retrieves the lowest sampling rate.SamplingRate.getNextHigherSamplingRate()Retrieves the next higher sampling rate or null if it is already the highest sampling rate.SamplingRate.getPreviousLowerSamplingRate()Retrieves the previous lower sampling rate or null if it is already the lowest sampling rate.static SamplingRateReturns the enum constant of this class with the specified name.static SamplingRate[]SamplingRate.values()Returns an array containing the constants of this enum class, in the order they are declared.