Uses of Interface
org.refcodes.audio.SamplingRateAccessor
-
Uses of SamplingRateAccessor in org.refcodes.audio
Subinterfaces of SamplingRateAccessor in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceAmplitudeBuilder<S extends SoundAmplitude, B extends AmplitudeBuilder<S,B>> Base interface for sample builders such as theMonoAmplitudeBuilderor theSoundAmplitudeBuilder.interfaceAmplitudeReader<S extends SoundAmplitude>TheAmplitudeReaderreads sound samples from a stream or a file.interfaceAmplitudeWriter<S extends SoundAmplitude, B extends AmplitudeWriter<S,B>> TheAmplitudeWriterwrites sound samples to a stream or a file.interfaceCsvAmplitudeWriter<S extends SoundAmplitude, B extends CsvAmplitudeWriter<S,B>> Base definition of a WAV sample writer.interfaceTheCurveFunctionSoundAmplitudeBuildermakes it easy to create sound samples for some (trigonometric) functions.interfaceLineOutAmplitudeWriter<S extends SoundAmplitude, B extends LineOutAmplitudeWriter<S,B>> Base definition of a line-out sample writer.interfaceAMonoAmplitudeis aSoundAmplitudesupporting just one single channel.interfaceTheMonoAmplitudeBuilderextends theSoundAmplitudewith builder functionality.interfaceTheMonoAmplitudeReaderreads sound samples from a stream or a file.interfaceMonoAmplitudeWriter<B extends MonoAmplitudeWriter<B>>TheMonoAmplitudeWriterwrites sound samples to a stream or a file.static interfaceProvides a sampling rate property.interfaceASoundAmplituderepresents a sample assigned to an according time positioning.interfaceTheSoundAmplitudeBuilderextends theSoundAmplitudewith builder functionality.interfaceTheSoundAmplitudeReaderreads sound samples from a stream or a file.interfaceSoundAmplitudeWriter<B extends SoundAmplitudeWriter<B>>TheSoundAmplitudeWriterwrites sound samples to a stream or a file.interfaceWavAmplitudeWriter<S extends SoundAmplitude, B extends WavAmplitudeWriter<S,B>> Base definition of a WAV sample writer.Classes in org.refcodes.audio that implement SamplingRateAccessorModifier and TypeClassDescriptionclassAbstractCsvAmplitudeReader<S extends SoundAmplitude>TheAbstractCsvAmplitudeReaderprovides a foundation to read sound samples from a CSV file.classAbstractCsvAmplitudeWriter<S extends SoundAmplitude, B extends CsvAmplitudeWriter<S,B>> TheAbstractCsvAmplitudeWriterprovides a foundation to write sound samples to a CSV file.classAbstractLineOutAmplitudeWriter<S extends SoundAmplitude, B extends LineOutAmplitudeWriter<S,B>> TheAbstractLineOutAmplitudeWriterprovides a foundation means to write sound samples to a line-out device.classAbstractSvgAmplitudeWriter<S extends SoundAmplitude, B extends AmplitudeWriter<S,B>> TheAbstractSvgAmplitudeWriterprovides a foundation to write sound samples to a SVG file.classAbstractWavAmplitudeWriter<S extends SoundAmplitude, B extends WavAmplitudeWriter<S,B>> TheAbstractWavAmplitudeWriterprovides a foundation means to write sound samples to a WAV file.classTheCsvMonoAmplitudeReaderprovides means to read sound samples from a CSV file.classTheCsvMonoAmplitudeWriterprovides means to write sound samples to a CSV file.classTheCsvSoundAmplitudeReaderprovides means to read sound samples from a CSV file.classTheCsvSoundAmplitudeWriterprovides means to write sound samples to a CSV file.classTheCurveFunctionSoundAmplitudeBuilderImplimplements theCurveFunctionSoundAmplitudeBuilderinterface.classTheLineOutMonoAmplitudeWriterprovides means to write sound samples to a line-out device.classTheLineOutSoundAmplitudeWriterprovides means to write sound samples to a line-out device.classAMonoAmplitudeBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classAMonoAmplitudeImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classASoundAmplitudeBuilderrepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classASoundAmplituderepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classTheSvgMonoAmplitudeWriterprovides means to write sound samples to a SVG file.classTheWavMonoAmplitudeWriterprovides means to write sound samples to a WAV file.classTheWavSoundAmplitudeWriterprovides means to write sound samples to a WAV file.