Uses of Interface
org.refcodes.audio.SamplingRateAccessor.SamplingRateBuilder
-
Uses of SamplingRateAccessor.SamplingRateBuilder in org.refcodes.audio
Classes in org.refcodes.audio with type parameters of type SamplingRateAccessor.SamplingRateBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a sampling rate property returning the builder for applying multiple build operations.Subinterfaces of SamplingRateAccessor.SamplingRateBuilder in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> Base definition of a WAV sample writer.interfaceTheCurveFunctionSoundSampleBuildermakes it easy to create sound samples for some (trigonometric) functions.interfaceLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> Base definition of a line-out sample writer.interfaceTheMonoSampleBuilderextends theSoundSamplewith builder functionality.interfaceMonoSampleWriter<B extends MonoSampleWriter<B>>TheMonoSampleWriterwrites sound samples to a stream or a file.interfaceSampleBuilder<S extends SoundSample,B extends SampleBuilder<S, B>> Base interface for sample builders such as theMonoSampleBuilderor theSoundSampleBuilder.interfaceSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheSampleWriterwrites sound samples to a stream or a file.interfaceTheSoundSampleBuilderextends theSoundSamplewith builder functionality.interfaceSoundSampleWriter<B extends SoundSampleWriter<B>>TheSoundSampleWriterwrites sound samples to a stream or a file.interfaceWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> Base definition of a WAV sample writer.Classes in org.refcodes.audio that implement SamplingRateAccessor.SamplingRateBuilderModifier and TypeClassDescriptionclassAbstractCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> TheAbstractCsvSampleWriterprovides a foundation to write sound samples to a CSV file.classAbstractLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> TheAbstractLineOutSampleWriterprovides a foundation means to write sound samples to a line-out device.classAbstractSvgSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheAbstractSvgSampleWriterprovides a foundation to write sound samples to a SVG file.classAbstractWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> TheAbstractWavSampleWriterprovides a foundation means to write sound samples to a WAV file.classTheCsvMonoSampleWriterprovides means to write sound samples to a CSV file.classTheCsvSoundSampleWriterprovides means to write sound samples to a CSV file.classTheCurveFunctionSoundSampleBuilderImplimplements theCurveFunctionSoundSampleBuilderinterface.classTheLineOutMonoSampleWriterprovides means to write sound samples to a line-out device.classTheLineOutSoundSampleWriterprovides means to write sound samples to a line-out device.classAMonoSampleBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classASoundSampleBuilderrepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classTheSvgMonoSampleWriterprovides means to write sound samples to a SVG file.classTheWavMonoSampleWriterprovides means to write sound samples to a WAV file.classTheWavSoundSampleWriterprovides means to write sound samples to a WAV file.