Uses of Interface
org.refcodes.audio.SamplingRateAccessor.SamplingRateProperty
-
Uses of SamplingRateAccessor.SamplingRateProperty in org.refcodes.audio
Subinterfaces of SamplingRateAccessor.SamplingRateProperty in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceAmplitudeBuilder<S extends SoundAmplitude, B extends AmplitudeBuilder<S,B>> Base interface for sample builders such as theMonoAmplitudeBuilderor theSoundAmplitudeBuilder.interfaceAmplitudeWriter<S extends SoundAmplitude, B extends AmplitudeWriter<S,B>> TheAmplitudeWriterwrites sound samples to a stream or a file.interfaceCsvAmplitudeWriter<S extends SoundAmplitude, B extends CsvAmplitudeWriter<S,B>> Base definition of a WAV sample writer.interfaceTheCurveFunctionSoundAmplitudeBuildermakes it easy to create sound samples for some (trigonometric) functions.interfaceLineOutAmplitudeWriter<S extends SoundAmplitude, B extends LineOutAmplitudeWriter<S,B>> Base definition of a line-out sample writer.interfaceTheMonoAmplitudeBuilderextends theSoundAmplitudewith builder functionality.interfaceMonoAmplitudeWriter<B extends MonoAmplitudeWriter<B>>TheMonoAmplitudeWriterwrites sound samples to a stream or a file.interfaceTheSoundAmplitudeBuilderextends theSoundAmplitudewith builder functionality.interfaceSoundAmplitudeWriter<B extends SoundAmplitudeWriter<B>>TheSoundAmplitudeWriterwrites sound samples to a stream or a file.interfaceWavAmplitudeWriter<S extends SoundAmplitude, B extends WavAmplitudeWriter<S,B>> Base definition of a WAV sample writer.Classes in org.refcodes.audio that implement SamplingRateAccessor.SamplingRatePropertyModifier and TypeClassDescriptionclassAbstractCsvAmplitudeWriter<S extends SoundAmplitude, B extends CsvAmplitudeWriter<S,B>> TheAbstractCsvAmplitudeWriterprovides a foundation to write sound samples to a CSV file.classAbstractLineOutAmplitudeWriter<S extends SoundAmplitude, B extends LineOutAmplitudeWriter<S,B>> TheAbstractLineOutAmplitudeWriterprovides a foundation means to write sound samples to a line-out device.classAbstractSvgAmplitudeWriter<S extends SoundAmplitude, B extends AmplitudeWriter<S,B>> TheAbstractSvgAmplitudeWriterprovides a foundation to write sound samples to a SVG file.classAbstractWavAmplitudeWriter<S extends SoundAmplitude, B extends WavAmplitudeWriter<S,B>> TheAbstractWavAmplitudeWriterprovides a foundation means to write sound samples to a WAV file.classTheCsvMonoAmplitudeWriterprovides means to write sound samples to a CSV file.classTheCsvSoundAmplitudeWriterprovides means to write sound samples to a CSV file.classTheCurveFunctionSoundAmplitudeBuilderImplimplements theCurveFunctionSoundAmplitudeBuilderinterface.classTheLineOutMonoAmplitudeWriterprovides means to write sound samples to a line-out device.classTheLineOutSoundAmplitudeWriterprovides means to write sound samples to a line-out device.classAMonoAmplitudeBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classASoundAmplitudeBuilderrepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classTheSvgMonoAmplitudeWriterprovides means to write sound samples to a SVG file.classTheWavMonoAmplitudeWriterprovides means to write sound samples to a WAV file.classTheWavSoundAmplitudeWriterprovides means to write sound samples to a WAV file.