Uses of Interface
org.refcodes.audio.SoundSample
-
Uses of SoundSample in org.refcodes.audio
Classes in org.refcodes.audio with type parameters of type SoundSampleModifier and TypeClassDescriptionclassAbstractCsvSampleReader<S extends SoundSample>TheAbstractCsvSampleReaderprovides a foundation to read sound samples from a CSV file.classAbstractCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> TheAbstractCsvSampleWriterprovides a foundation to write sound samples to a CSV file.classAbstractLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> TheAbstractLineOutSampleWriterprovides a foundation means to write sound samples to a line-out device.classAbstractSvgSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheAbstractSvgSampleWriterprovides a foundation to write sound samples to a SVG file.classAbstractWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> TheAbstractWavSampleWriterprovides a foundation means to write sound samples to a WAV file.interfaceCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> Base definition of a WAV sample writer.interfaceLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> Base definition of a line-out sample writer.interfaceSampleBuilder<S extends SoundSample,B extends SampleBuilder<S, B>> Base interface for sample builders such as theMonoSampleBuilderor theSoundSampleBuilder.interfaceSampleReader<S extends SoundSample>TheSampleReaderreads sound samples from a stream or a file.interfaceSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheSampleWriterwrites sound samples to a stream or a file.interfaceWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> Base definition of a WAV sample writer.Subinterfaces of SoundSample in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceAMonoSampleis aSoundSamplesupporting just one single channel.interfaceTheMonoSampleBuilderextends theSoundSamplewith builder functionality.interfaceSampleBuilder<S extends SoundSample,B extends SampleBuilder<S, B>> Base interface for sample builders such as theMonoSampleBuilderor theSoundSampleBuilder.interfaceTheSoundSampleBuilderextends theSoundSamplewith builder functionality.Classes in org.refcodes.audio that implement SoundSampleModifier and TypeClassDescriptionclassAMonoSampleBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classAMonoSampleImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classASoundSampleBuilderrepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classASoundSamplerepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.Methods in org.refcodes.audio that return SoundSampleMethods in org.refcodes.audio with parameters of type SoundSampleModifier and TypeMethodDescriptionprotected static SourceDataLineAbstractLineOutSampleWriter.toLineOut(SoundSample aSoundSample, BitsPerSample aBitsPerSample) Produces a line-outSourceDataLineinstance for writing samples to.voidCsvSoundSampleWriter.writeNext(SoundSample aSample) Writes the next samples, one sample for each channel.voidLineOutSoundSampleWriter.writeNext(SoundSample aSample) Writes the next samples, one sample for each channel.voidSoundSampleWriter.writeNext(SoundSample aSample) Writes the next samples, one sample for each channel.voidWavSoundSampleWriter.writeNext(SoundSample aSample) Writes the next samples, one sample for each channel.Constructors in org.refcodes.audio with parameters of type SoundSampleModifierConstructorDescriptionSoundSampleBuilderImpl(SoundSample aSoundSample) Constructs aSoundSampleImplinstance with the according sound sample's settingsSoundSampleImpl(SoundSample aSample) Constructs aSoundSampleinstance with the according sound sample's settings