Uses of Interface
org.refcodes.audio.SoundSampleWriter
-
Uses of SoundSampleWriter in org.refcodes.audio
Classes in org.refcodes.audio with type parameters of type SoundSampleWriterModifier and TypeInterfaceDescriptioninterfaceSoundSampleWriter<B extends SoundSampleWriter<B>>TheSoundSampleWriterwrites sound samples to a stream or a file.Classes in org.refcodes.audio that implement SoundSampleWriterModifier and TypeClassDescriptionclassTheCsvSoundSampleWriterprovides means to write sound samples to a CSV file.classTheLineOutSoundSampleWriterprovides means to write sound samples to a line-out device.classTheWavSoundSampleWriterprovides means to write sound samples to a WAV file.