All Classes and Interfaces
Class
Description
The
AbstractCsvAmplitudeReader provides a foundation to read sound
samples from a CSV file.The
AbstractCsvAmplitudeWriter provides a foundation to write sound
samples to a CSV file.The
AbstractLineOutAmplitudeWriter provides a foundation means to
write sound samples to a line-out device.The
AbstractSvgAmplitudeWriter provides a foundation to write sound
samples to a SVG file.The
AbstractWavAmplitudeWriter provides a foundation means to write
sound samples to a WAV file.Base interface for sample builders such as the
MonoAmplitudeBuilder
or the SoundAmplitudeBuilder.The
AmplitudeReader reads sound samples from a stream or a file.The
AmplitudeWriter writes sound samples to a stream or a file.The
BitsPerAmplitude enumeration defines some common bits/amplitude
per channel constants.Provides an accessor for a bits/amplitude per channel property.
Provides a builder method for a bits/amplitude per channel property
returning the builder for applying multiple build operations.
Provides a mutator for a bits/amplitude per channel property.
Provides a bits/amplitude per channel property.
Base definition of a WAV sample writer.
The
CsvDeltaMode defines for which values of a SoundAmplitude
only the delta between the current SoundAmplitude being written and
the previous SoundAmplitude being written are written to the next row
of the CSV file.The
CsvMonoAmplitudeReader provides means to read sound samples from
a CSV file.The
CsvMonoAmplitudeWriter provides means to write sound samples to a
CSV file.The
CsvSoundAmplitudeReader provides means to read sound samples from
a CSV file.The
CsvSoundAmplitudeWriter provides means to write sound samples to
a CSV file.Enumeration containing some predefined trigonometric functions.
The
CurveFunctionSoundAmplitudeBuilder makes it easy to create sound
samples for some (trigonometric) functions.The
CurveFunctionSoundAmplitudeBuilderImpl implements the
CurveFunctionSoundAmplitudeBuilder interface.Base definition of a line-out sample writer.
The
LineOutMonoAmplitudeWriter provides means to write sound samples
to a line-out device.The
LineOutSoundAmplitudeWriter provides means to write sound samples
to a line-out device.A
MonoAmplitude is a SoundAmplitude supporting just one
single channel.The
MonoAmplitudeBuilder extends the SoundAmplitude with
builder functionality.A
MonoAmplitudeBuilderImpl represents a single amplitude (one for the
mono channel) assigned to an according time positioning.A
MonoAmplitudeImpl represents a single amplitude (one for the mono
channel) assigned to an according time positioning.The
MonoAmplitudeReader reads sound samples from a stream or a file.The
MonoAmplitudeWriter writes sound samples to a stream or a file.The
SamplingRate enumeration defines some common sampling rates.Provides an accessor for a sampling rate property.
Provides a builder method for a sampling rate property returning the
builder for applying multiple build operations.
Provides a mutator for a sampling rate property.
Provides a sampling rate property.
A
SoundAmplitude represents a sample assigned to an according time
positioning.The
SoundAmplitudeBuilder extends the SoundAmplitude with
builder functionality.A
SoundAmplitudeBuilder represents multiple amplitudes (one for each
channel,e.g. two in case we have classical stereo sound) assigned to an
according time positioning.A
SoundAmplitude represents multiple amplitudes (one for each
channel,e.g. two in case we have classical stereo sound) assigned to an
according time positioning.The
SoundAmplitudeReader reads sound samples from a stream or a file.The
SoundAmplitudeWriter writes sound samples to a stream or a file.The
SvgMonoAmplitudeWriter provides means to write sound samples to a
SVG file.Base definition of a WAV sample writer.
The
WavMonoAmplitudeWriter provides means to write sound samples to a
WAV file.The
WavSoundAmplitudeWriter provides means to write sound samples to
a WAV file.