- All Superinterfaces:
org.refcodes.mixin.IndexAccessor,SamplingRateAccessor,org.refcodes.mixin.TimeStampAccessor
- All Known Subinterfaces:
MonoSample,MonoSampleBuilder,SampleBuilder<S,,B> SoundSampleBuilder
- All Known Implementing Classes:
MonoSampleBuilderImpl,MonoSampleImpl,SoundSampleBuilderImpl,SoundSampleImpl
public interface SoundSample
extends SamplingRateAccessor, org.refcodes.mixin.IndexAccessor, org.refcodes.mixin.TimeStampAccessor
A
SoundSample represents a sample assigned to an according time
positioning. A sample is a value or set of values at a point in time. In case
of mono audio, a sample represents a single value, in case of stereo audio, a
sample represents a set of values, one value represents one channel (e.g. two
channels when we have a left and a right speaker).-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.IndexAccessor
org.refcodes.mixin.IndexAccessor.IndexBuilder<B extends org.refcodes.mixin.IndexAccessor.IndexBuilder<B>>, org.refcodes.mixin.IndexAccessor.IndexMutator, org.refcodes.mixin.IndexAccessor.IndexPropertyNested classes/interfaces inherited from interface org.refcodes.audio.SamplingRateAccessor
SamplingRateAccessor.SamplingRateBuilder<B extends SamplingRateAccessor.SamplingRateBuilder<B>>, SamplingRateAccessor.SamplingRateMutator, SamplingRateAccessor.SamplingRatePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TimeStampAccessor
org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B extends org.refcodes.mixin.TimeStampAccessor.TimeStampBuilder<B>>, org.refcodes.mixin.TimeStampAccessor.TimeStampMutator, org.refcodes.mixin.TimeStampAccessor.TimeStampProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault intDetermines the number of channels this sample is ought for.double[]Returns the sample's data for the according time positioning.doubleReturns the position in time of this sound sample in ms.Methods inherited from interface org.refcodes.mixin.IndexAccessor
getIndexMethods inherited from interface org.refcodes.audio.SamplingRateAccessor
getSamplingRate
-
Method Details
-
getSampleData
double[] getSampleData()Returns the sample's data for the according time positioning. A sample is a value or set of values at a point in time. In case of mono audio, a sample represents a single value, in case of stereo audio, a sample represents a set of values, one value represents one channel (e.g. two channels when we have a left and a right speaker).- Returns:
- The sample's data for the according time positioning.
-
getChannelCount
default int getChannelCount()Determines the number of channels this sample is ought for.- Returns:
- The number of channels this sample feeds.
-
getTimeStamp
double getTimeStamp()Returns the position in time of this sound sample in ms.- Specified by:
getTimeStampin interfaceorg.refcodes.mixin.TimeStampAccessor- Returns:
- The sound sample's time positioning.
-