Uses of Enum Class
org.refcodes.audio.CurveFunctionFunction
-
Uses of CurveFunctionFunction in org.refcodes.audio
Methods in org.refcodes.audio that return CurveFunctionFunctionModifier and TypeMethodDescriptionstatic CurveFunctionFunctionReturns the enum constant of this class with the specified name.static CurveFunctionFunction[]CurveFunctionFunction.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.audio with parameters of type CurveFunctionFunctionModifier and TypeMethodDescriptiondefault voidCurveFunctionSoundSampleBuilder.setTrigonometricFunction(CurveFunctionFunction aFunction) Sets the trigonometric function to be used when generatingMonoSample.default CurveFunctionSoundSampleBuilderCurveFunctionSoundSampleBuilder.withTrigonometricFunction(CurveFunctionFunction aFunction) Builder method for setting the trigonometric function to be used when generatingMonoSampleinstances.