Uses of Interface
org.refcodes.audio.LineOutSampleWriter
-
-
Uses of LineOutSampleWriter in org.refcodes.audio
Classes in org.refcodes.audio with type parameters of type LineOutSampleWriter Modifier and Type Class Description classAbstractLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S,B>>TheAbstractLineOutSampleWriterprovides a foundation means to write sound samples to a line-out device.interfaceLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S,B>>Base definition of a line-out sample writer.Classes in org.refcodes.audio that implement LineOutSampleWriter Modifier and Type Class Description classAbstractLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S,B>>TheAbstractLineOutSampleWriterprovides a foundation means to write sound samples to a line-out device.classLineOutMonoSampleWriterTheLineOutMonoSampleWriterprovides means to write sound samples to a line-out device.classLineOutSoundSampleWriterTheLineOutSoundSampleWriterprovides means to write sound samples to a line-out device.
-