Uses of Interface
org.refcodes.audio.MonoSample
-
-
Uses of MonoSample in org.refcodes.audio
Subinterfaces of MonoSample in org.refcodes.audio Modifier and Type Interface Description interfaceMonoSampleBuilderTheMonoSampleBuilderextends theSoundSamplewith builder functionality.Classes in org.refcodes.audio that implement MonoSample Modifier and Type Class Description classMonoSampleBuilderImplAMonoSampleBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classMonoSampleImplAMonoSampleImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.Methods in org.refcodes.audio that return MonoSample Modifier and Type Method Description MonoSampleCurveFunctionSoundSampleBuilder. next()Returns the nextMonoSamplefor the current index (as ofCurveFunctionSoundSampleBuilder.getIndex()) as well as for the other builder's settings and increases the index by one.MonoSampleCurveFunctionSoundSampleBuilderImpl. next()Returns the nextMonoSamplefor the current index (as ofCurveFunctionSoundSampleBuilder.getIndex()) as well as for the other builder's settings and increases the index by one.MonoSampleCsvMonoSampleReader. nextRow()MonoSampleCurveFunctionSoundSampleBuilder. toMonoSample()Creates aMonoSampleas of the builder's settings.MonoSampleCurveFunctionSoundSampleBuilder. toMonoSample(int aIndex)Creates aMonoSamplefor the given index and the the builder's settings.MonoSampleCurveFunctionSoundSampleBuilderImpl. toMonoSample()Creates aMonoSampleas of the builder's settings.MonoSampleCurveFunctionSoundSampleBuilderImpl. toMonoSample(int index)Creates aMonoSamplefor the given index and the the builder's settings.Methods in org.refcodes.audio with parameters of type MonoSample Modifier and Type Method Description voidCsvMonoSampleWriter. writeNext(MonoSample aSample)Writes the next samples, one sample for each channel.voidLineOutMonoSampleWriter. writeNext(MonoSample aSample)Writes the next samples, one sample for each channel.voidSvgMonoSampleWriter. writeNext(MonoSample aSample)Writes the next samples, one sample for each channel.voidWavMonoSampleWriter. writeNext(MonoSample aSample)Writes the next samples, one sample for each channel.Constructors in org.refcodes.audio with parameters of type MonoSample Constructor Description MonoSampleBuilderImpl(MonoSample aSample)Constructs aMonoSampleinstance with the according sound sample's settingsMonoSampleImpl(MonoSample aSample)Constructs aMonoSampleinstance with the according sound sample's settings
-