Uses of Interface
org.refcodes.audio.SampleReader
-
-
Uses of SampleReader in org.refcodes.audio
Subinterfaces of SampleReader in org.refcodes.audio Modifier and Type Interface Description interfaceMonoSampleReaderTheMonoSampleReaderreads sound samples from a stream or a file.interfaceSoundSampleReaderTheSoundSampleReaderreads sound samples from a stream or a file.Classes in org.refcodes.audio that implement SampleReader Modifier and Type Class Description classAbstractCsvSampleReader<S extends SoundSample>TheAbstractCsvSampleReaderprovides a foundation to read sound samples from a CSV file.classCsvMonoSampleReaderTheCsvMonoSampleReaderprovides means to read sound samples from a CSV file.classCsvSoundSampleReaderTheCsvSoundSampleReaderprovides means to read sound samples from a CSV file.
-