Uses of Class
org.refcodes.audio.SamplingRate
-
-
Uses of SamplingRate in org.refcodes.audio
Methods in org.refcodes.audio that return SamplingRate Modifier and Type Method Description static SamplingRateSamplingRate. getHigestSamplingRate()Retrieves the highest sampling rate.static SamplingRateSamplingRate. getLowestSamplingRate()Retrieves the lowest sampling rate.SamplingRateSamplingRate. getNextHigherSamplingRate()Retrieves the next higher sampling rate or null if it is already the highest sampling rate.SamplingRateSamplingRate. getPreviousLowerSamplingRate()Retrieves the previous lower sampling rate or null if it is already the lowest sampling rate.static SamplingRateSamplingRate. valueOf(String name)Returns the enum constant of this type with the specified name.static SamplingRate[]SamplingRate. values()Returns an array containing the constants of this enum type, in the order they are declared.
-