Uses of Interface
org.refcodes.audio.SamplingRateAccessor
-
Uses of SamplingRateAccessor in org.refcodes.audio
Subinterfaces of SamplingRateAccessor in org.refcodes.audioModifier and TypeInterfaceDescriptioninterfaceCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> Base definition of a WAV sample writer.interfaceTheCurveFunctionSoundSampleBuildermakes it easy to create sound samples for some (trigonometric) functions.interfaceLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> Base definition of a line-out sample writer.interfaceAMonoSampleis aSoundSamplesupporting just one single channel.interfaceTheMonoSampleBuilderextends theSoundSamplewith builder functionality.interfaceTheMonoSampleReaderreads sound samples from a stream or a file.interfaceMonoSampleWriter<B extends MonoSampleWriter<B>>TheMonoSampleWriterwrites sound samples to a stream or a file.interfaceSampleBuilder<S extends SoundSample,B extends SampleBuilder<S, B>> Base interface for sample builders such as theMonoSampleBuilderor theSoundSampleBuilder.interfaceSampleReader<S extends SoundSample>TheSampleReaderreads sound samples from a stream or a file.interfaceSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheSampleWriterwrites sound samples to a stream or a file.static interfaceProvides a sampling rate property.interfaceASoundSamplerepresents a sample assigned to an according time positioning.interfaceTheSoundSampleBuilderextends theSoundSamplewith builder functionality.interfaceTheSoundSampleReaderreads sound samples from a stream or a file.interfaceSoundSampleWriter<B extends SoundSampleWriter<B>>TheSoundSampleWriterwrites sound samples to a stream or a file.interfaceWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> Base definition of a WAV sample writer.Classes in org.refcodes.audio that implement SamplingRateAccessorModifier and TypeClassDescriptionclassAbstractCsvSampleReader<S extends SoundSample>TheAbstractCsvSampleReaderprovides a foundation to read sound samples from a CSV file.classAbstractCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S, B>> TheAbstractCsvSampleWriterprovides a foundation to write sound samples to a CSV file.classAbstractLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S, B>> TheAbstractLineOutSampleWriterprovides a foundation means to write sound samples to a line-out device.classAbstractSvgSampleWriter<S extends SoundSample,B extends SampleWriter<S, B>> TheAbstractSvgSampleWriterprovides a foundation to write sound samples to a SVG file.classAbstractWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S, B>> TheAbstractWavSampleWriterprovides a foundation means to write sound samples to a WAV file.classTheCsvMonoSampleReaderprovides means to read sound samples from a CSV file.classTheCsvMonoSampleWriterprovides means to write sound samples to a CSV file.classTheCsvSoundSampleReaderprovides means to read sound samples from a CSV file.classTheCsvSoundSampleWriterprovides means to write sound samples to a CSV file.classTheCurveFunctionSoundSampleBuilderImplimplements theCurveFunctionSoundSampleBuilderinterface.classTheLineOutMonoSampleWriterprovides means to write sound samples to a line-out device.classTheLineOutSoundSampleWriterprovides means to write sound samples to a line-out device.classAMonoSampleBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classAMonoSampleImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classASoundSampleBuilderrepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classASoundSamplerepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classTheSvgMonoSampleWriterprovides means to write sound samples to a SVG file.classTheWavMonoSampleWriterprovides means to write sound samples to a WAV file.classTheWavSoundSampleWriterprovides means to write sound samples to a WAV file.