Uses of Interface
org.refcodes.audio.SamplingRateAccessor.SamplingRateProperty
-
-
Uses of SamplingRateAccessor.SamplingRateProperty in org.refcodes.audio
Subinterfaces of SamplingRateAccessor.SamplingRateProperty in org.refcodes.audio Modifier and Type Interface Description interfaceCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S,B>>Base definition of a WAV sample writer.interfaceCurveFunctionSoundSampleBuilderTheCurveFunctionSoundSampleBuildermakes it easy to create sound samples for some (trigonometric) functions.interfaceLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S,B>>Base definition of a line-out sample writer.interfaceMonoSampleBuilderTheMonoSampleBuilderextends theSoundSamplewith builder functionality.interfaceMonoSampleWriter<B extends MonoSampleWriter<B>>TheMonoSampleWriterwrites sound samples to a stream or a file.interfaceSampleBuilder<S extends SoundSample,B extends SampleBuilder<S,B>>Base interface for sample builders such as theMonoSampleBuilderor theSoundSampleBuilder.interfaceSampleWriter<S extends SoundSample,B extends SampleWriter<S,B>>TheSampleWriterwrites sound samples to a stream or a file.interfaceSoundSampleBuilderTheSoundSampleBuilderextends theSoundSamplewith builder functionality.interfaceSoundSampleWriter<B extends SoundSampleWriter<B>>TheSoundSampleWriterwrites sound samples to a stream or a file.interfaceWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S,B>>Base definition of a WAV sample writer.Classes in org.refcodes.audio that implement SamplingRateAccessor.SamplingRateProperty Modifier and Type Class Description classAbstractCsvSampleWriter<S extends SoundSample,B extends CsvSampleWriter<S,B>>TheAbstractCsvSampleWriterprovides a foundation to write sound samples to a CSV file.classAbstractLineOutSampleWriter<S extends SoundSample,B extends LineOutSampleWriter<S,B>>TheAbstractLineOutSampleWriterprovides a foundation means to write sound samples to a line-out device.classAbstractSvgSampleWriter<S extends SoundSample,B extends SampleWriter<S,B>>TheAbstractSvgSampleWriterprovides a foundation to write sound samples to a SVG file.classAbstractWavSampleWriter<S extends SoundSample,B extends WavSampleWriter<S,B>>TheAbstractWavSampleWriterprovides a foundation means to write sound samples to a WAV file.classCsvMonoSampleWriterTheCsvMonoSampleWriterprovides means to write sound samples to a CSV file.classCsvSoundSampleWriterTheCsvSoundSampleWriterprovides means to write sound samples to a CSV file.classCurveFunctionSoundSampleBuilderImplTheCurveFunctionSoundSampleBuilderImplimplements theCurveFunctionSoundSampleBuilderinterface.classLineOutMonoSampleWriterTheLineOutMonoSampleWriterprovides means to write sound samples to a line-out device.classLineOutSoundSampleWriterTheLineOutSoundSampleWriterprovides means to write sound samples to a line-out device.classMonoSampleBuilderImplAMonoSampleBuilderImplrepresents a single amplitude (one for the mono channel) assigned to an according time positioning.classSoundSampleBuilderImplASoundSampleBuilderrepresents multiple amplitudes (one for each channel,e.g. two in case we have classical stereo sound) assigned to an according time positioning.classSvgMonoSampleWriterTheSvgMonoSampleWriterprovides means to write sound samples to a SVG file.classWavMonoSampleWriterTheWavMonoSampleWriterprovides means to write sound samples to a WAV file.classWavSoundSampleWriterTheWavSoundSampleWriterprovides means to write sound samples to a WAV file.
-