Uses of Interface
org.refcodes.audio.SoundSampleWriter
-
-
Uses of SoundSampleWriter in org.refcodes.audio
Classes in org.refcodes.audio with type parameters of type SoundSampleWriter Modifier and Type Interface Description interfaceSoundSampleWriter<B extends SoundSampleWriter<B>>TheSoundSampleWriterwrites sound samples to a stream or a file.Classes in org.refcodes.audio that implement SoundSampleWriter Modifier and Type Class Description classCsvSoundSampleWriterTheCsvSoundSampleWriterprovides means to write sound samples to a CSV file.classLineOutSoundSampleWriterTheLineOutSoundSampleWriterprovides means to write sound samples to a line-out device.classWavSoundSampleWriterTheWavSoundSampleWriterprovides means to write sound samples to a WAV file.
-